Update Readme
=============

Don't forget to update README.md:

1. Remove the Dependencies section if there is any
2. Modify the Installation section according to the template bellow.
3. Update copyright information if neccessary

Installation
------------

This project uses [Nuvola SDK](https://github.com/tiliado/nuvolasdk#create-new-project). Please refer to
the [Build a Project Using Nuvola SDK](https://github.com/tiliado/nuvolasdk#build-a-project-using-nuvola-sdk)
page in order to obtain information about dependencies and installation instructions.
